@@ -76,6 +76,51 @@ def test_kbhit_interrupted():
     assert math.floor(time.time() - stime) == 1.0
 
 
+def test_kbhit_interrupted_nonetype():
+    """kbhit() should also allow interruption with timeout of None."""
+    pid, master_fd = pty.fork()
+    if pid is 0:
+        try:
+            cov = __import__('cov_core_init').init()
+        except ImportError:
+            cov = None
+
+        # child pauses, writes semaphore and begins awaiting input
+        global got_sigwinch
+        got_sigwinch = False
+
+        def on_resize(sig, action):
+            global got_sigwinch
+            got_sigwinch = True
+
+        term = TestTerminal()
+        signal.signal(signal.SIGWINCH, on_resize)
+        read_until_semaphore(sys.__stdin__.fileno(), semaphore=SEMAPHORE)
+        os.write(sys.__stdout__.fileno(), SEMAPHORE)
+        with term.raw():
+            term.inkey(timeout=None)
+        os.write(sys.__stdout__.fileno(), b'complete')
+        assert got_sigwinch is True
+        if cov is not None:
+            cov.stop()
+            cov.save()
+        os._exit(0)
+
+    with echo_off(master_fd):
+        os.write(master_fd, SEND_SEMAPHORE)
+        read_until_semaphore(master_fd)
+        stime = time.time()
+        time.sleep(1.0)
+        os.kill(pid, signal.SIGWINCH)
+        os.write(master_fd, 'X')
+        output = read_until_eof(master_fd)
+
+    pid, status = os.waitpid(pid, 0)
+    assert output == u'complete'
+    assert os.WEXITSTATUS(status) == 0
+    assert math.floor(time.time() - stime) == 1.0
+
+
 def test_cbreak_no_kb():
     """cbreak() should not call tty.setcbreak() without keyboard"""
     @as_subprocess
